==> haskell-implicit-hie-0.1.4.0-70.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie
version:              0.1.4.0
visibility:           public
id:                   implicit-hie-0.1.4.0-9puXQ5ClVVI6Ed4F3hu9IY
key:                  implicit-hie-0.1.4.0-9puXQ5ClVVI6Ed4F3hu9IY
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  606850e9d2585b1d64bcde36bef29dad
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/implicit-hie-0.1.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/implicit-hie-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/implicit-hie-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.4.0-9puXQ5ClVVI6Ed4F3hu9IY
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    directory-1.3.8.5 filepath-1.4.300.1
    filepattern-0.1.3-68iNgnGhWl0Lmdh6l8Oknh text-2.0.2
    transformers-0.6.1.0 yaml-0.11.11.2-GyIObvMByN0941lpfsiwCu

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-0.1.4.0-71-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie
version:              0.1.4.0
visibility:           public
id:                   implicit-hie-0.1.4.0-6gHANNr4w6g2WMvlW7rWZC
key:                  implicit-hie-0.1.4.0-6gHANNr4w6g2WMvlW7rWZC
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  41a3ebe4029852b9b79b971f6a0aeb67
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/implicit-hie-0.1.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/implicit-hie-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/implicit-hie-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.4.0-6gHANNr4w6g2WMvlW7rWZC
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    directory-1.3.8.5 filepath-1.4.300.1
    filepattern-0.1.3-7I7lGPmfNPY5UpecGXOj1c text-2.0.2
    transformers-0.6.1.0 yaml-0.11.11.2-HJgRwey6BMIIq0hOFQKRBa

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
